##
## interfaces.py
from zope import schema
from waeup.sirp.interfaces import IWAeUPObject
from waeup.sirp.payments.vocabularies import (
    payment_states, payment_categories)

class IPaymentsContainer(IWAeUPObject):
    """A container for all kind of payment objects.

    """

class IPayment(IWAeUPObject):
    """A base representation of payments.

    """

    p_state = schema.Choice(
        title = u'Payment State',
        default = u'unpaid',
        vocabulary = payment_states,
        required = True,
        )

    p_category = schema.Choice(
        title = u'Payment Category',
        default = u'schoolfee',
        vocabulary = payment_categories,
        required = True,
        )

    p_item = schema.TextLine(
        title = u'Payment Item',
        default = u'Certificate XYZ',
        required = False,
        )

    date_of_creation = schema.Date(
        title = u'Ticket Creation Date',
        )

    date_of_payment = schema.Date(
        title = u'Date of Payment',
        )

    amount_auth = schema.Int(
        title = u'Amount authorized',
        default = 0,
        required = True,
        )

class ISCPayment(IPayment):
    """A scratch card payment.

    """

    p_code = schema.TextLine(
        title = u'Payment Access Code',
        default = u'Certificate XYZ',
        required = False,
        )

class IOnlinePayment(IPayment):
    """A payment via payment gateways.

    """

    surcharge = schema.Int(
        title = u'Surcharge',
        default = 0,
        required = False,
        )

    order_id = schema.TextLine(
        title = u'Order Id',
        default = None,
        )

    r_amount_approved = schema.Int(
        title = u'Response Amount Approved',
        default = 0,
        required = False,
        )

    r_code = schema.TextLine(
        title = u'Response Code',
        default = None,
        )

    r_card_num = schema.TextLine(
        title = u'Response Card Number',
        default = None,
        )